﻿// Copyright (c) Six Labors and contributors.
// Licensed under the Apache License, Version 2.0.

namespace SixLabors.ImageSharp.PixelFormats
{
    /// <content>
    /// Provides operators and composition algorithms.
    /// </content>
    public partial struct RgbaVector
    {
        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F0F8FF.
        /// </summary>
        public static readonly RgbaVector AliceBlue = NamedColors<RgbaVector>.AliceBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FAEBD7.
        /// </summary>
        public static readonly RgbaVector AntiqueWhite = NamedColors<RgbaVector>.AntiqueWhite;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #00FFFF.
        /// </summary>
        public static readonly RgbaVector Aqua = NamedColors<RgbaVector>.Aqua;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #7FFFD4.
        /// </summary>
        public static readonly RgbaVector Aquamarine = NamedColors<RgbaVector>.Aquamarine;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F0FFFF.
        /// </summary>
        public static readonly RgbaVector Azure = NamedColors<RgbaVector>.Azure;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F5F5DC.
        /// </summary>
        public static readonly RgbaVector Beige = NamedColors<RgbaVector>.Beige;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFE4C4.
        /// </summary>
        public static readonly RgbaVector Bisque = NamedColors<RgbaVector>.Bisque;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #000000.
        /// </summary>
        public static readonly RgbaVector Black = NamedColors<RgbaVector>.Black;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFEBCD.
        /// </summary>
        public static readonly RgbaVector BlanchedAlmond = NamedColors<RgbaVector>.BlanchedAlmond;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #0000FF.
        /// </summary>
        public static readonly RgbaVector Blue = NamedColors<RgbaVector>.Blue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #8A2BE2.
        /// </summary>
        public static readonly RgbaVector BlueViolet = NamedColors<RgbaVector>.BlueViolet;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #A52A2A.
        /// </summary>
        public static readonly RgbaVector Brown = NamedColors<RgbaVector>.Brown;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #DEB887.
        /// </summary>
        public static readonly RgbaVector BurlyWood = NamedColors<RgbaVector>.BurlyWood;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #5F9EA0.
        /// </summary>
        public static readonly RgbaVector CadetBlue = NamedColors<RgbaVector>.CadetBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #7FFF00.
        /// </summary>
        public static readonly RgbaVector Chartreuse = NamedColors<RgbaVector>.Chartreuse;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #D2691E.
        /// </summary>
        public static readonly RgbaVector Chocolate = NamedColors<RgbaVector>.Chocolate;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FF7F50.
        /// </summary>
        public static readonly RgbaVector Coral = NamedColors<RgbaVector>.Coral;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #6495ED.
        /// </summary>
        public static readonly RgbaVector CornflowerBlue = NamedColors<RgbaVector>.CornflowerBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFF8DC.
        /// </summary>
        public static readonly RgbaVector Cornsilk = NamedColors<RgbaVector>.Cornsilk;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #DC143C.
        /// </summary>
        public static readonly RgbaVector Crimson = NamedColors<RgbaVector>.Crimson;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #00FFFF.
        /// </summary>
        public static readonly RgbaVector Cyan = NamedColors<RgbaVector>.Cyan;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #00008B.
        /// </summary>
        public static readonly RgbaVector DarkBlue = NamedColors<RgbaVector>.DarkBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #008B8B.
        /// </summary>
        public static readonly RgbaVector DarkCyan = NamedColors<RgbaVector>.DarkCyan;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #B8860B.
        /// </summary>
        public static readonly RgbaVector DarkGoldenrod = NamedColors<RgbaVector>.DarkGoldenrod;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #A9A9A9.
        /// </summary>
        public static readonly RgbaVector DarkGray = NamedColors<RgbaVector>.DarkGray;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #006400.
        /// </summary>
        public static readonly RgbaVector DarkGreen = NamedColors<RgbaVector>.DarkGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #BDB76B.
        /// </summary>
        public static readonly RgbaVector DarkKhaki = NamedColors<RgbaVector>.DarkKhaki;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #8B008B.
        /// </summary>
        public static readonly RgbaVector DarkMagenta = NamedColors<RgbaVector>.DarkMagenta;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #556B2F.
        /// </summary>
        public static readonly RgbaVector DarkOliveGreen = NamedColors<RgbaVector>.DarkOliveGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FF8C00.
        /// </summary>
        public static readonly RgbaVector DarkOrange = NamedColors<RgbaVector>.DarkOrange;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #9932CC.
        /// </summary>
        public static readonly RgbaVector DarkOrchid = NamedColors<RgbaVector>.DarkOrchid;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #8B0000.
        /// </summary>
        public static readonly RgbaVector DarkRed = NamedColors<RgbaVector>.DarkRed;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #E9967A.
        /// </summary>
        public static readonly RgbaVector DarkSalmon = NamedColors<RgbaVector>.DarkSalmon;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #8FBC8B.
        /// </summary>
        public static readonly RgbaVector DarkSeaGreen = NamedColors<RgbaVector>.DarkSeaGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #483D8B.
        /// </summary>
        public static readonly RgbaVector DarkSlateBlue = NamedColors<RgbaVector>.DarkSlateBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #2F4F4F.
        /// </summary>
        public static readonly RgbaVector DarkSlateGray = NamedColors<RgbaVector>.DarkSlateGray;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #00CED1.
        /// </summary>
        public static readonly RgbaVector DarkTurquoise = NamedColors<RgbaVector>.DarkTurquoise;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #9400D3.
        /// </summary>
        public static readonly RgbaVector DarkViolet = NamedColors<RgbaVector>.DarkViolet;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FF1493.
        /// </summary>
        public static readonly RgbaVector DeepPink = NamedColors<RgbaVector>.DeepPink;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #00BFFF.
        /// </summary>
        public static readonly RgbaVector DeepSkyBlue = NamedColors<RgbaVector>.DeepSkyBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #696969.
        /// </summary>
        public static readonly RgbaVector DimGray = NamedColors<RgbaVector>.DimGray;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #1E90FF.
        /// </summary>
        public static readonly RgbaVector DodgerBlue = NamedColors<RgbaVector>.DodgerBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #B22222.
        /// </summary>
        public static readonly RgbaVector Firebrick = NamedColors<RgbaVector>.Firebrick;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFFAF0.
        /// </summary>
        public static readonly RgbaVector FloralWhite = NamedColors<RgbaVector>.FloralWhite;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #228B22.
        /// </summary>
        public static readonly RgbaVector ForestGreen = NamedColors<RgbaVector>.ForestGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FF00FF.
        /// </summary>
        public static readonly RgbaVector Fuchsia = NamedColors<RgbaVector>.Fuchsia;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #DCDCDC.
        /// </summary>
        public static readonly RgbaVector Gainsboro = NamedColors<RgbaVector>.Gainsboro;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F8F8FF.
        /// </summary>
        public static readonly RgbaVector GhostWhite = NamedColors<RgbaVector>.GhostWhite;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFD700.
        /// </summary>
        public static readonly RgbaVector Gold = NamedColors<RgbaVector>.Gold;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #DAA520.
        /// </summary>
        public static readonly RgbaVector Goldenrod = NamedColors<RgbaVector>.Goldenrod;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #808080.
        /// </summary>
        public static readonly RgbaVector Gray = NamedColors<RgbaVector>.Gray;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #008000.
        /// </summary>
        public static readonly RgbaVector Green = NamedColors<RgbaVector>.Green;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #ADFF2F.
        /// </summary>
        public static readonly RgbaVector GreenYellow = NamedColors<RgbaVector>.GreenYellow;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F0FFF0.
        /// </summary>
        public static readonly RgbaVector Honeydew = NamedColors<RgbaVector>.Honeydew;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FF69B4.
        /// </summary>
        public static readonly RgbaVector HotPink = NamedColors<RgbaVector>.HotPink;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #CD5C5C.
        /// </summary>
        public static readonly RgbaVector IndianRed = NamedColors<RgbaVector>.IndianRed;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #4B0082.
        /// </summary>
        public static readonly RgbaVector Indigo = NamedColors<RgbaVector>.Indigo;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFFFF0.
        /// </summary>
        public static readonly RgbaVector Ivory = NamedColors<RgbaVector>.Ivory;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F0E68C.
        /// </summary>
        public static readonly RgbaVector Khaki = NamedColors<RgbaVector>.Khaki;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #E6E6FA.
        /// </summary>
        public static readonly RgbaVector Lavender = NamedColors<RgbaVector>.Lavender;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFF0F5.
        /// </summary>
        public static readonly RgbaVector LavenderBlush = NamedColors<RgbaVector>.LavenderBlush;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #7CFC00.
        /// </summary>
        public static readonly RgbaVector LawnGreen = NamedColors<RgbaVector>.LawnGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFFACD.
        /// </summary>
        public static readonly RgbaVector LemonChiffon = NamedColors<RgbaVector>.LemonChiffon;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #ADD8E6.
        /// </summary>
        public static readonly RgbaVector LightBlue = NamedColors<RgbaVector>.LightBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F08080.
        /// </summary>
        public static readonly RgbaVector LightCoral = NamedColors<RgbaVector>.LightCoral;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #E0FFFF.
        /// </summary>
        public static readonly RgbaVector LightCyan = NamedColors<RgbaVector>.LightCyan;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FAFAD2.
        /// </summary>
        public static readonly RgbaVector LightGoldenrodYellow = NamedColors<RgbaVector>.LightGoldenrodYellow;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #D3D3D3.
        /// </summary>
        public static readonly RgbaVector LightGray = NamedColors<RgbaVector>.LightGray;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #90EE90.
        /// </summary>
        public static readonly RgbaVector LightGreen = NamedColors<RgbaVector>.LightGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFB6C1.
        /// </summary>
        public static readonly RgbaVector LightPink = NamedColors<RgbaVector>.LightPink;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFA07A.
        /// </summary>
        public static readonly RgbaVector LightSalmon = NamedColors<RgbaVector>.LightSalmon;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #20B2AA.
        /// </summary>
        public static readonly RgbaVector LightSeaGreen = NamedColors<RgbaVector>.LightSeaGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #87CEFA.
        /// </summary>
        public static readonly RgbaVector LightSkyBlue = NamedColors<RgbaVector>.LightSkyBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #778899.
        /// </summary>
        public static readonly RgbaVector LightSlateGray = NamedColors<RgbaVector>.LightSlateGray;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #B0C4DE.
        /// </summary>
        public static readonly RgbaVector LightSteelBlue = NamedColors<RgbaVector>.LightSteelBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFFFE0.
        /// </summary>
        public static readonly RgbaVector LightYellow = NamedColors<RgbaVector>.LightYellow;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #00FF00.
        /// </summary>
        public static readonly RgbaVector Lime = NamedColors<RgbaVector>.Lime;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #32CD32.
        /// </summary>
        public static readonly RgbaVector LimeGreen = NamedColors<RgbaVector>.LimeGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FAF0E6.
        /// </summary>
        public static readonly RgbaVector Linen = NamedColors<RgbaVector>.Linen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FF00FF.
        /// </summary>
        public static readonly RgbaVector Magenta = NamedColors<RgbaVector>.Magenta;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #800000.
        /// </summary>
        public static readonly RgbaVector Maroon = NamedColors<RgbaVector>.Maroon;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #66CDAA.
        /// </summary>
        public static readonly RgbaVector MediumAquamarine = NamedColors<RgbaVector>.MediumAquamarine;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #0000CD.
        /// </summary>
        public static readonly RgbaVector MediumBlue = NamedColors<RgbaVector>.MediumBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #BA55D3.
        /// </summary>
        public static readonly RgbaVector MediumOrchid = NamedColors<RgbaVector>.MediumOrchid;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #9370DB.
        /// </summary>
        public static readonly RgbaVector MediumPurple = NamedColors<RgbaVector>.MediumPurple;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #3CB371.
        /// </summary>
        public static readonly RgbaVector MediumSeaGreen = NamedColors<RgbaVector>.MediumSeaGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #7B68EE.
        /// </summary>
        public static readonly RgbaVector MediumSlateBlue = NamedColors<RgbaVector>.MediumSlateBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #00FA9A.
        /// </summary>
        public static readonly RgbaVector MediumSpringGreen = NamedColors<RgbaVector>.MediumSpringGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #48D1CC.
        /// </summary>
        public static readonly RgbaVector MediumTurquoise = NamedColors<RgbaVector>.MediumTurquoise;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #C71585.
        /// </summary>
        public static readonly RgbaVector MediumVioletRed = NamedColors<RgbaVector>.MediumVioletRed;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #191970.
        /// </summary>
        public static readonly RgbaVector MidnightBlue = NamedColors<RgbaVector>.MidnightBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F5FFFA.
        /// </summary>
        public static readonly RgbaVector MintCream = NamedColors<RgbaVector>.MintCream;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFE4E1.
        /// </summary>
        public static readonly RgbaVector MistyRose = NamedColors<RgbaVector>.MistyRose;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFE4B5.
        /// </summary>
        public static readonly RgbaVector Moccasin = NamedColors<RgbaVector>.Moccasin;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFDEAD.
        /// </summary>
        public static readonly RgbaVector NavajoWhite = NamedColors<RgbaVector>.NavajoWhite;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #000080.
        /// </summary>
        public static readonly RgbaVector Navy = NamedColors<RgbaVector>.Navy;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FDF5E6.
        /// </summary>
        public static readonly RgbaVector OldLace = NamedColors<RgbaVector>.OldLace;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #808000.
        /// </summary>
        public static readonly RgbaVector Olive = NamedColors<RgbaVector>.Olive;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #6B8E23.
        /// </summary>
        public static readonly RgbaVector OliveDrab = NamedColors<RgbaVector>.OliveDrab;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFA500.
        /// </summary>
        public static readonly RgbaVector Orange = NamedColors<RgbaVector>.Orange;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FF4500.
        /// </summary>
        public static readonly RgbaVector OrangeRed = NamedColors<RgbaVector>.OrangeRed;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #DA70D6.
        /// </summary>
        public static readonly RgbaVector Orchid = NamedColors<RgbaVector>.Orchid;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #EEE8AA.
        /// </summary>
        public static readonly RgbaVector PaleGoldenrod = NamedColors<RgbaVector>.PaleGoldenrod;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #98FB98.
        /// </summary>
        public static readonly RgbaVector PaleGreen = NamedColors<RgbaVector>.PaleGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #AFEEEE.
        /// </summary>
        public static readonly RgbaVector PaleTurquoise = NamedColors<RgbaVector>.PaleTurquoise;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #DB7093.
        /// </summary>
        public static readonly RgbaVector PaleVioletRed = NamedColors<RgbaVector>.PaleVioletRed;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFEFD5.
        /// </summary>
        public static readonly RgbaVector PapayaWhip = NamedColors<RgbaVector>.PapayaWhip;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFDAB9.
        /// </summary>
        public static readonly RgbaVector PeachPuff = NamedColors<RgbaVector>.PeachPuff;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #CD853F.
        /// </summary>
        public static readonly RgbaVector Peru = NamedColors<RgbaVector>.Peru;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFC0CB.
        /// </summary>
        public static readonly RgbaVector Pink = NamedColors<RgbaVector>.Pink;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #DDA0DD.
        /// </summary>
        public static readonly RgbaVector Plum = NamedColors<RgbaVector>.Plum;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #B0E0E6.
        /// </summary>
        public static readonly RgbaVector PowderBlue = NamedColors<RgbaVector>.PowderBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #800080.
        /// </summary>
        public static readonly RgbaVector Purple = NamedColors<RgbaVector>.Purple;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #663399.
        /// </summary>
        public static readonly RgbaVector RebeccaPurple = NamedColors<RgbaVector>.RebeccaPurple;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FF0000.
        /// </summary>
        public static readonly RgbaVector Red = NamedColors<RgbaVector>.Red;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #BC8F8F.
        /// </summary>
        public static readonly RgbaVector RosyBrown = NamedColors<RgbaVector>.RosyBrown;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #4169E1.
        /// </summary>
        public static readonly RgbaVector RoyalBlue = NamedColors<RgbaVector>.RoyalBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #8B4513.
        /// </summary>
        public static readonly RgbaVector SaddleBrown = NamedColors<RgbaVector>.SaddleBrown;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FA8072.
        /// </summary>
        public static readonly RgbaVector Salmon = NamedColors<RgbaVector>.Salmon;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F4A460.
        /// </summary>
        public static readonly RgbaVector SandyBrown = NamedColors<RgbaVector>.SandyBrown;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #2E8B57.
        /// </summary>
        public static readonly RgbaVector SeaGreen = NamedColors<RgbaVector>.SeaGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFF5EE.
        /// </summary>
        public static readonly RgbaVector SeaShell = NamedColors<RgbaVector>.SeaShell;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #A0522D.
        /// </summary>
        public static readonly RgbaVector Sienna = NamedColors<RgbaVector>.Sienna;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #C0C0C0.
        /// </summary>
        public static readonly RgbaVector Silver = NamedColors<RgbaVector>.Silver;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #87CEEB.
        /// </summary>
        public static readonly RgbaVector SkyBlue = NamedColors<RgbaVector>.SkyBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #6A5ACD.
        /// </summary>
        public static readonly RgbaVector SlateBlue = NamedColors<RgbaVector>.SlateBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #708090.
        /// </summary>
        public static readonly RgbaVector SlateGray = NamedColors<RgbaVector>.SlateGray;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFFAFA.
        /// </summary>
        public static readonly RgbaVector Snow = NamedColors<RgbaVector>.Snow;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #00FF7F.
        /// </summary>
        public static readonly RgbaVector SpringGreen = NamedColors<RgbaVector>.SpringGreen;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #4682B4.
        /// </summary>
        public static readonly RgbaVector SteelBlue = NamedColors<RgbaVector>.SteelBlue;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #D2B48C.
        /// </summary>
        public static readonly RgbaVector Tan = NamedColors<RgbaVector>.Tan;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #008080.
        /// </summary>
        public static readonly RgbaVector Teal = NamedColors<RgbaVector>.Teal;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #D8BFD8.
        /// </summary>
        public static readonly RgbaVector Thistle = NamedColors<RgbaVector>.Thistle;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FF6347.
        /// </summary>
        public static readonly RgbaVector Tomato = NamedColors<RgbaVector>.Tomato;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFFFFF.
        /// </summary>
        public static readonly RgbaVector Transparent = NamedColors<RgbaVector>.Transparent;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #40E0D0.
        /// </summary>
        public static readonly RgbaVector Turquoise = NamedColors<RgbaVector>.Turquoise;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #EE82EE.
        /// </summary>
        public static readonly RgbaVector Violet = NamedColors<RgbaVector>.Violet;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F5DEB3.
        /// </summary>
        public static readonly RgbaVector Wheat = NamedColors<RgbaVector>.Wheat;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFFFFF.
        /// </summary>
        public static readonly RgbaVector White = NamedColors<RgbaVector>.White;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #F5F5F5.
        /// </summary>
        public static readonly RgbaVector WhiteSmoke = NamedColors<RgbaVector>.WhiteSmoke;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #FFFF00.
        /// </summary>
        public static readonly RgbaVector Yellow = NamedColors<RgbaVector>.Yellow;

        /// <summary>
        /// Represents a <see cref="RgbaVector"/> matching the W3C definition that has an hex value of #9ACD32.
        /// </summary>
        public static readonly RgbaVector YellowGreen = NamedColors<RgbaVector>.YellowGreen;
    }
}